@@ -1,16 +1,9 @@
-#' Scrape DESCRIPTION from CRAN for each pkg.
-#'
-#' @inheritParams pkgDep
-#' @inheritParams makeRepo
-#' @import XML
-#' @export
-#' 
-#' @example /inst/examples/example_getCranDescription.R
-getCranDescription <- function(pkg, repos = getOption("repos"), 
-                               type = "source", 
-                               pkgs = pkgDep(pkg, repos=repos, type=type)){
 
-  getOne <- function(package){
+#' @importFrom XML readHTMLTable
+oldGetCranDescription <- function(pkg, repos = getOption("repos"), 
+                                  type = "source", 
+                                  pkgs = pkgDep(pkg, repos = repos, type = type)){
+  getOne <- function(package) {
     repos <- repos[[1]]
     if(!grepl("/$", repos)) repos <- paste0(repos, "/")
     
@@ -19,8 +12,8 @@ getCranDescription <- function(pkg, repos = getOption("repos"),
     )
     x <- tryCatch({
       text <- paste(readLines(url), collapse = "\n")
-      XML::readHTMLTable(text, header=FALSE, which=1, stringsAsFactors=FALSE)
-    }, error=function(e) e
+      XML::readHTMLTable(text, header = FALSE, which = 1, stringsAsFactors = FALSE)
+    }, error = function(e) e
     )
     if(inherits(x, "error")) {
       warning("Package ", package, " not found on CRAN")
@@ -33,8 +26,30 @@ getCranDescription <- function(pkg, repos = getOption("repos"),
     }
   }
   ret <- do.call(rbind, lapply(pkgs, getOne))
-  ret <- reshape(ret, direction="wide", timevar="Field", idvar="Package", v.names="Value")
+  ret <- reshape(ret, direction = "wide", timevar = "Field", idvar = "Package", v.names = "Value")
   names(ret) <- gsub("Value.", "", names(ret))
   rownames(ret) <- ret$Package
   ret
 }
+
+#' Scrape DESCRIPTION from CRAN for each pkg.
+#'
+#' @inheritParams pkgDep
+#' @inheritParams makeRepo
+#' 
+#' @export
+#' 
+#' @example /inst/examples/example_getCranDescription.R
+getCranDescription <- function(pkg, repos = getOption("repos"), 
+                               type = "source", 
+                               pkgs = pkgDep(pkg, repos = repos, type = type)){
+  
+  if(getRversion() >= "3.4.1"){
+    pdb <- tools::CRAN_package_db()
+    pdb[match(pkgs, pdb$Package), ]
+  } else {
+    oldGetCranDescription(pkg = pkg, repos = repos, type = type, pkgs = pkgs)
+  }
+}
+
+
