@@ -6,25 +6,26 @@ pdb <- cranJuly2014
 \dontrun{
   pdb <- pkgAvail(
     repos = c(CRAN = "http://mran.microsoft.com"),
-    type="source"
+    type = "source"
   )
 }
 
-dg <- makeDepGraph(tags, availPkgs = pdb  , includeBasePkgs=FALSE, suggests=TRUE, enhances=TRUE)
+dg <- makeDepGraph(tags, availPkgs = pdb  , includeBasePkgs = FALSE,
+                   suggests = TRUE, enhances = TRUE)
 
 set.seed(42); 
 plot(dg)
 
 # Move edge legend to top left
 set.seed(42); 
-plot(dg, legendPosition=c(-1, 1))
+plot(dg, legendPosition = c(-1, 1))
 
 # Change font size and shape size
 set.seed(42); 
-plot(dg, legendPosition=c(-1, 1), vertex.size=20,  cex=0.5)
+plot(dg, legendPosition = c(-1, 1), vertex.size = 20,  cex = 0.5)
 
 
 # Move vertex legend to top right
 set.seed(42); 
-plot(dg, legendPosition=c(1, 1), vertex.size=20,  cex=0.5)
+plot(dg, legendPosition = c(1, 1), vertex.size = 20,  cex = 0.5)
 
